@@ -2,4 +2,4 @@ foo <- 1
 
 head_mtcars <- head(mtcars2)
 
-helper_baz <- testLoadHelpers::baz
+helper_baz <- baz
